@@ -18,12 +18,13 @@ import logging
 import re
 import time
 from abc import abstractmethod
+from collections.abc import Generator, Iterable
 from enum import Enum
 from pathlib import Path
 from typing import Any
-from collections.abc import Generator, Iterable
 from urllib.parse import urlparse
 
+import duckdb
 import pandas as pd
 import pyarrow
 import pyarrow as pa
@@ -32,18 +33,18 @@ from cloudpathlib import AnyPath
 from fsspec.implementations.local import LocalFileSystem
 from pyarrow import ArrowIndexError, ArrowInvalid
 
-from mostlyai.sdk._data.exceptions import MostlyDataException
 from mostlyai.sdk._data.base import (
     DataContainer,
     DataTable,
     order_df_by,
 )
-from mostlyai.sdk._data.util.common import SCHEME_SEP, DATA_TABLE_METADATA_FIELDS, OrderBy
 from mostlyai.sdk._data.dtype import (
     PandasDType,
     coerce_dtypes_by_encoding,
     pyarrow_to_pandas_map,
 )
+from mostlyai.sdk._data.exceptions import MostlyDataException
+from mostlyai.sdk._data.util.common import DATA_TABLE_METADATA_FIELDS, SCHEME_SEP, OrderBy, assert_read_only_sql
 
 FILE_DATA_TABLE_LAZY_INIT_FIELDS = DATA_TABLE_METADATA_FIELDS + [
     "columns",
@@ -281,9 +282,9 @@ class FileDataTable(DataTable, abc.ABC):
     def read_data(
         self,
         where: dict[str, Any] | None = None,
-        limit_n_rows: int | None = None,
+        limit: int | None = None,
         columns: list[str] | None = None,
-        is_shuffle: bool | None = False,
+        shuffle: bool | None = False,
         order_by: OrderBy | None = None,
         do_coerce_dtypes: bool | None = False,
     ) -> pd.DataFrame:
@@ -300,10 +301,10 @@ class FileDataTable(DataTable, abc.ABC):
                 split_blocks=True,
             )
         )
-        if is_shuffle:
+        if shuffle:
             df = df.sample(frac=1)
-        if limit_n_rows is not None:
-            df = df.head(limit_n_rows)
+        if limit is not None:
+            df = df.head(limit)
         if order_by:
             df = order_df_by(df, order_by)
         if do_coerce_dtypes:
@@ -365,6 +366,15 @@ class FileDataTable(DataTable, abc.ABC):
     def _get_columns(self) -> list[str]:
         return [c.name for c in self.dataset.schema if c.name != ""]
 
+    def handle_if_exists(self, if_exists: str = "fail") -> str:
+        destination_exists = self.container.path.exists()
+        if destination_exists:
+            if if_exists == "fail":
+                raise MostlyDataException("Destination location already exists.")
+            elif if_exists == "append" and self.IS_WRITE_APPEND_ALLOWED:
+                return "a"
+        return "w"
+
 
 class FileContainer(DataContainer):
     SCHEMES = ["http", "https"]
@@ -484,6 +494,41 @@ class FileContainer(DataContainer):
         self.set_uri(location)
         return {"location": location}
 
+    def _init_duckdb(self, con: duckdb.DuckDBPyConnection) -> None:
+        pass
+
+    @staticmethod
+    def _create_duckdb_secret(con: duckdb.DuckDBPyConnection, secret_params: dict[str, Any]) -> None:
+        def sql_escape(val: str) -> str:
+            return str(val).replace("'", "''")  # escape single quotes for SQL strings
+
+        # all values must be wrapped in single quotes and escaped
+        parts = [f"{key} '{sql_escape(value)}'" for key, value in secret_params.items()]
+        joined_parts = ",\n    ".join(parts)
+        create_secret_sql = f"CREATE SECRET (\n    {joined_parts}\n);"
+
+        con.execute(create_secret_sql)
+
+    def query(self, sql: str) -> pd.DataFrame:
+        assert_read_only_sql(sql)
+        try:
+            with duckdb.connect(database=":memory:") as con:
+                con.execute("""
+                    SET disabled_filesystems = 'LocalFileSystem';
+                    SET allow_community_extensions = false;
+                    SET lock_configuration = true;
+                """)
+                self._init_duckdb(con)
+                result = con.execute(sql).fetchdf()
+
+            return result
+        except duckdb.IOException as e:
+            _LOG.error(f"IO Error executing query: {str(e)}")
+            raise
+        except duckdb.Error as e:
+            _LOG.error(f"DuckDB Error executing query: {str(e)}")
+            raise
+
 
 class LocalFileContainer(FileContainer):
     SCHEMES = ["file"]
