@@ -14,13 +14,12 @@
 import logging
 import uuid
 import zipfile
-from collections import defaultdict
 from pathlib import Path
 from typing import Literal
 
 import pandas as pd
 
-from mostlyai.sdk._data.base import Schema, NonContextRelation, ForeignKey
+from mostlyai.sdk._data.base import ForeignKey, NonContextRelation, Schema
 from mostlyai.sdk._data.dtype import is_timestamp_dtype
 from mostlyai.sdk._data.file.base import LocalFileContainer
 from mostlyai.sdk._data.file.table.csv import CsvDataTable
@@ -28,10 +27,11 @@ from mostlyai.sdk._data.file.table.parquet import ParquetDataTable
 from mostlyai.sdk._data.non_context import postproc_non_context
 from mostlyai.sdk._data.progress_callback import ProgressCallback, ProgressCallbackWrapper
 from mostlyai.sdk._data.util.common import (
-    NON_CONTEXT_COLUMN_INFIX,
     IS_NULL,
+    NON_CONTEXT_COLUMN_INFIX,
 )
-from mostlyai.sdk.domain import Generator, SyntheticDataset, ModelEncodingType
+from mostlyai.sdk._local.storage import get_model_label
+from mostlyai.sdk.domain import Generator, ModelType, SyntheticDataset
 
 _LOG = logging.getLogger(__name__)
 
@@ -42,9 +42,11 @@ def execute_step_finalize_generation(
     is_probe: bool,
     job_workspace_dir: Path,
     update_progress: ProgressCallback | None = None,
-) -> list[dict]:
-    usage = calculate_usage(schema)
-
+) -> dict[str, int]:
+    # get synthetic table usage
+    usages = dict()
+    for table_name, table in schema.tables.items():
+        usages.update({table_name: table.row_count})
     # short circuit for probing
     delivery_dir = job_workspace_dir / "FinalizedSyntheticData"
     if is_probe:
@@ -55,11 +57,14 @@ def execute_step_finalize_generation(
                 delivery_dir=delivery_dir,
                 export_csv=False,
             )
-        return usage
+        return usages
 
     random_samples_dir = job_workspace_dir / "RandomSamples"
     zip_dir = job_workspace_dir / "ZIP"
-    export_csv = sum([t["total_datapoints"] for t in usage]) < 100_000_000  # only export CSV if datapoints < 100M
+
+    # calculate total datapoints (rows × columns) across all tables
+    total_datapoints = sum(table.row_count * len(table.columns) for table in schema.tables.values())
+    export_csv = total_datapoints < 100_000_000  # only export CSV if datapoints < 100M
 
     with ProgressCallbackWrapper(update_progress, description="Finalize generation") as progress:
         # init progress with total_count; +4 for the 4 steps below
@@ -94,43 +99,13 @@ def execute_step_finalize_generation(
             zip_data(delivery_dir=delivery_dir, format="csv", out_dir=zip_dir)
             progress.update(advance=1)
 
-    return usage
+        return usages
 
 
-def calculate_usage(schema: Schema) -> list[dict]:
-    usage = []
-    for table_name, table in schema.tables.items():
-        n_rows = table.row_count
-        # language columns depend on the average length (of a sample)
-        language_columns = [
-            col for col in table.columns if table.encoding_types[col] == ModelEncodingType.language_text
-        ]
-        language_samples = next(table.read_chunks(columns=language_columns, fetch_chunk_size=1_000))
-        # the weight of any non-language columns is 1
-        assumed_avg_token_size = 5
-        column_weights = defaultdict(
-            lambda: 1,
-            {
-                col: language_samples[col].str.len().mean() / assumed_avg_token_size
-                if not language_samples[col].empty
-                else 1
-                for col in language_columns
-            },
-        )
-        if language_columns:
-            _LOG.info(f"{table=} has language columns with weights {dict(column_weights)} for usage calculation")
-        n_weighted_columns = sum(column_weights[col] for col in table.encoding_types)
-        total_datapoints = int(n_rows * n_weighted_columns)
-        usage.append(dict(table=table.name, total_datapoints=total_datapoints, total_rows=n_rows))
-    return usage
-
-
-def update_total_rows_and_datapoints(synthetic_dataset: SyntheticDataset, usage: list[dict]):
-    for table_usage in usage:
-        table = next(t for t in synthetic_dataset.tables if t.name == table_usage["table"])
-        table.total_rows = table_usage["total_rows"]
-        table.total_datapoints = table_usage["total_datapoints"]
-    return usage
+def update_total_rows(synthetic_dataset: SyntheticDataset, usages: dict[str, int]) -> None:
+    for table_name, total_rows in usages.items():
+        table = next(t for t in synthetic_dataset.tables if t.name == table_name)
+        table.total_rows = total_rows
 
 
 def format_datetime(df: pd.DataFrame) -> pd.DataFrame:
@@ -451,7 +426,7 @@ def create_generation_schema(
     for table in generator.tables:
         # create LocalFileContainer
         container = LocalFileContainer()
-        model_label = f"{table.name}:tabular"
+        model_label = get_model_label(table, ModelType.tabular, path_safe=True)
         location = str(job_workspace_dir / model_label / "SyntheticData")
         container.set_location(location)
         if step == "pull_context_data":
@@ -477,4 +452,6 @@ def create_generation_schema(
             for fk in table.foreign_keys or []
         ]
         tables[table.name] = data_table
-    return Schema(tables=tables)
+    schema = Schema(tables=tables)
+    schema.preprocess_schema_before_pull()
+    return schema
